sqlobject.tests.test_combining_joins module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_combining_joins module

class `sqlobject.tests.test_combining_joins.` `Complex`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `complex_group`
  property `complex_groupID`
  `j` = complex
  property `name`
  `q` = complex
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_combining_joins.Complex`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'complex'
  `unit_models`

class `sqlobject.tests.test_combining_joins.` `ComplexGroup`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `complexes`
  `j` = complex_group
  property `name`
  `q` = complex_group
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_combining_joins.ComplexGroup`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'complex_group'
  property `unit_models`

class `sqlobject.tests.test_combining_joins.` `UnitModel`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `complexes`
  `j` = unit_model
  property `name`
  `q` = unit_model
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `defaultOrderBy` = 'name'
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_combining_joins.UnitModel`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'unit_model'

`sqlobject.tests.test_combining_joins.` `test_join_sqlrepr`()